@@ -105,6 +105,8 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               is_number_geographical,
                               is_number_type_geographical,
                               is_possible_number,
+                              is_possible_number_for_type,
+                              is_possible_number_for_type_with_reason,
                               is_possible_number_string,
                               is_possible_number_with_reason,
                               is_valid_number,
@@ -121,6 +123,8 @@ from .phonenumberutil import (COUNTRY_CODE_TO_REGION_CODE, SUPPORTED_REGIONS,
                               region_code_for_country_code,
                               region_codes_for_country_code,
                               region_code_for_number,
+                              supported_types_for_region,
+                              supported_types_for_non_geo_entity,
                               truncate_too_long_number,
                               is_mobile_number_portable_region,)
 from .shortnumberinfo import (ShortNumberCost,
@@ -139,7 +143,7 @@ from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "8.3.3"
+__version__ = "8.4.0"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
@@ -172,6 +176,8 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'is_number_type_geographical',
            'is_number_match',
            'is_possible_number',
+           'is_possible_number_for_type',
+           'is_possible_number_for_type_with_reason',
            'is_possible_number_string',
            'is_possible_number_with_reason',
            'is_valid_number',
@@ -187,6 +193,8 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'region_code_for_country_code',
            'region_codes_for_country_code',
            'region_code_for_number',
+           'supported_types_for_region',
+           'supported_types_for_non_geo_entity',
            'truncate_too_long_number',
            'is_mobile_number_portable_region',
            # end of items from phonenumberutil.py
